@@ -1,8 +1,9 @@
 /**
  *
- * $Id: MrmAppl.h,v 1.1 1997/02/20 22:28:19 miers Exp $
+ * $Id: MrmAppl.h,v 1.3 2000/10/11 09:54:35 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,8 +23,8 @@
  *
  **/
 
-#ifndef MRM_APPL_H
-#define MRM_APPL_H
+#ifndef _MRM_MRMAPPL_H
+#define _MRM_MRMAPPL_H
 
 /* first we include some X11 header files */
 #include <X11/Intrinsic.h>
@@ -34,4 +35,4 @@
 #include <Xm/XmP.h>
 #include <Mrm/MrmPublic.h>
 
-#endif /* MRM_APPL_H */
+#endif /* _MRM_MRMAPPL_H */
