@@ -1,8 +1,9 @@
 /**
  *
- * $Id: TextOutP.h,v 1.8 2000/05/24 22:55:46 hennessy Exp $
+ * $Id: TextOutP.h,v 1.9 2000/09/23 14:51:41 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -21,11 +22,13 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  **/
-#ifndef _XM_TEXT_OUT_P_H
-#define _XM_TEXT_OUT_P_H
+
+#ifndef _XM_TEXTOUTP_H
+#define _XM_TEXTOUTP_H
 
 #include <Xm/XmP.h>
 #include <Xm/Text.h>
+#include <limits.h>  /* for INT_MAX */
 
 #ifdef __cplusplus
 extern "C" {
@@ -247,4 +250,4 @@ extern Boolean _XmTextGetBaselines(Widget widget,
 }
 #endif
 
-#endif
+#endif /* _XM_TEXTOUTP_H */
