@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Xm.h.in,v 1.11 2000/08/29 15:12:51 amai Exp $
+ * $Id: Xm.h.in,v 1.16 2000/11/05 17:25:34 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 2000 LessTif Development Team
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -24,8 +24,8 @@
  **/
 
 
-#ifndef _XM_H
-#define _XM_H
+#ifndef _XM_XM_H
+#define _XM_XM_H
 
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
@@ -49,10 +49,10 @@ extern "C" {
 /* Version Information */
 
 #define LESSTIF_VERSION 0
-#define LESSTIF_REVISION 91
+#define LESSTIF_REVISION 92
 
 #define LesstifVersion (LESSTIF_VERSION * 1000 + LESSTIF_REVISION)
-#define LesstifVERSION_STRING "@(#)GNU/LessTif Version 1.2 Release 0.91.8"
+#define LesstifVERSION_STRING "@(#)GNU/LessTif Version 1.2 Release 0.92.6"
 
 /* since we're replacing Motif 1.2... */
 #define XmVERSION 1
@@ -63,13 +63,6 @@ extern "C" {
 
 extern int xmUseVersion;
 
-/* Sometimes we have to change the Lesstif binary interface, but we
- * can't really change the Motif version number (i.e., library version number).
- * If you configure with --enable-back-compat you will retain the original
- * Lesstif binary interface.
- */
-#define LESSTIF_BACK_COMPAT	0
-
 /* pixmap stuff */
 
 #define XmUNSPECIFIED_PIXMAP	2
@@ -294,11 +287,7 @@ enum {
 
 /* For toggle button stuff */
 enum {
-#if LESSTIF_BACK_COMPAT
-    XmN_OF_MANY,
-#else
     XmN_OF_MANY = 1,
-#endif
     XmONE_OF_MANY
 };
 
@@ -995,6 +984,7 @@ XmString XmStringSeparatorCreate(void);
 
 Dimension XmStringWidth(XmFontList fontList, XmString string);
 
+XmFontList XmStringCreateFontList( XFontStruct *font, XmStringCharSet charset);
 
 /*************************** FontList.c *****************************/
 
@@ -1049,8 +1039,14 @@ void XmImSetFocusValues(Widget w, ArgList args, Cardinal num_args);
 void XmImSetValues(Widget w, ArgList args, Cardinal num_args);
 void XmImUnsetFocus(Widget w);
 XIM XmImGetXIM(Widget w);
-int XmImMbLookupString(Widget w, XKeyPressedEvent *event, char *buf,                        int nbytes,
-		       KeySym *keysym, int *status);
+int XmImMbLookupString(Widget w,
+                       XKeyPressedEvent *event,
+                       char *buf,
+                       int nbytes,
+                       KeySym *keysym,
+                       int *status);
+void XmImMbResetIC(Widget widget, 
+                   char **mb);
 extern void XmImVaSetFocusValues(Widget w, ...);
 extern void XmImVaSetValues(Widget w, ...);
 
@@ -1059,4 +1055,4 @@ extern void XmImVaSetValues(Widget w, ...);
 }
 #endif
 
-#endif /* _XM_H */
+#endif /* _XM_XM_H */
